@@ -7,7 +7,7 @@ from glob import glob
 
 def TIMIT_file(file_directory):
 
-    train_test_directory = glob(f"{file_directory}/T*")#use own file directory
+    train_test_directory = glob(f"{file_directory}/t*")#use own file directory
     lst_filetypes =['phn','txt','wav','wrd']
 
     #create TRAIN/TEST key
